//***************** (c) 2008 BTC Korporacja ***********************************
//                     http://www kamami.com
// PROJECT  : ADC_POT
// BOARD    : ZL3ST7 (with ST7FLITE39F2B6 in socket U1)
// COMPILER : RKitSTM8 for Ride7
//
//******************************************************************************
//
//    THE SOFTWARE INCLUDED IN THIS FILE IS FOR GUIDANCE ONLY.
//    BTC KORPORACJA SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT
//    OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
//    FROM USE OF THIS SOFTWARE.
//
//******************************************************************************
//
// DESCRIPTION :
//    Simple AD conversion. Input voltage is selected by potentiometer P2.
//    Result of conversion is transmitted to PC.
//
//    Settings and connections on ZL3ST7
//        P2 (con7) - PB0 (con16)
//
//      if RS232 cable connected:
//        RxD (con7) - PB6 (con16)
//        TxD (con7) - PA7 (con15)
//
//      if UART2USB converter (ZL1USB_A or ZL4USB) connected:
//        RxU (con7) - PB6 (con16)
//        TxU (con7) - PA7 (con15)
//
//******************************************************************************
#include <ST7LITE3.H>
#include "USART.h"

unsigned int GetADC(unsigned char channel)
{
unsigned int value = 0;
ADCDRL |= (1 << 3);// SLOW
ADCCSR = channel; //
ADCCSR |= (1 << 5); // ADON
while(!(ADCCSR&(1 << 7)));// wait for EOC
value = (ADCDRL & 0x03); //
value |= (ADCDRH << 2);  // 
ADCCSR &= ~(1 << 5); // clear ADON
return value;
}
//-------------------------------------
// main program
//-------------------------------------
int main(void)
{
char str[5];
int voltage;
USART_Init(); // USART initialization

USART_PutChar('\r');
USART_PutString("*************************\r");
USART_PutString("**   ZL15AVR ADC_POT   **\r");
USART_PutString("**    www.kamami.com   **\r");
USART_PutString("*************************\r");

// infinite loop
do{
  voltage = GetADC(0);
  USART_PutString("Channel 0 Value:");
  USART_PutString(Hex((char) (voltage >> 8), str));
  USART_PutString(Hex((char) (voltage & 255), str));
  USART_PutString("\r");
}while(1);

return 0;
}
//-------------------------------------
// End of file
//-------------------------------------
